@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-use String::Charcount qw(count percentage);
+use String::Charcount ':all';
 
 my ($string, $count, $percentage);
  
@@ -11,7 +11,9 @@ $string = 'The lazy brown fox jumped over the cat sitting on the fence.';
 print $string,"\n";
 
 $count = count(\$string);
-print 'e exists ', $$count{e}, ' times',"\n";
+print 'e occurence: ', $$count{e},"\n";
  
 $percentage = percentage(\$string, $count);
-print 'e percentage - ', $$percentage{e}, '%',"\n";
+print 'e percentage: ', $$percentage{e}, '%',"\n";
+
+print 'unique characters: ', count_unique(\$string),"\n";
